@@ -135,7 +135,7 @@
 #'
 #' @importFrom R6 R6Class
 #' @importFrom assertthat assert_that is.flag has_attr is.error
-#' @importFrom stringi stri_match_first_regex
+#' @importFrom stringi stri_match_first_regex stri_trim_both stri_split_fixed
 #' @importFrom urltools url_decode
 #' @importFrom brotli brotli_decompress
 #' @importFrom utils modifyList
@@ -436,8 +436,8 @@ Request <- R6Class('Request',
 
     parse_cookies = function() {
       if (is.null(self$headers$Cookie)) return(list())
-      cookies <- trimws(strsplit(self$headers$Cookie, ';')[[1]])
-      cookies <- unlist(strsplit(cookies, '='))
+      cookies <- stri_trim_both(stri_split_fixed(self$headers$Cookie, ';')[[1]])
+      cookies <- unlist(stri_split_fixed(cookies, '=', n = 2))
       structure(
         as.list(url_decode(cookies[c(FALSE, TRUE)])),
         names = cookies[c(TRUE, FALSE)]
